function fabric2stress(dirPath, dr, pDia, cutoff, filterSize)

kbT = 300*1.38*10^-23;          % Thermal energy
a = pDia/2;                     % Particle radius
delta = (cutoff-pDia);          % Shell thickness
vBox = (dr*10^-6)^3;            % Local volume for calculating pointwise stress
scaling = kbT*(a/delta)/vBox;   % Prefactor in fron of fabric
sigma = filterSize;             % Smoothing filter size
Files = dir([dirPath '/*.csv']);
tfinal = length(Files);
fprintf(['We have ' num2str(tfinal) ' frames\n']);

for time = 1:tfinal
fileInPath = [dirPath Files(time).name];
fabric = csvread(fileInPath);
fprintf([fileInPath '\n']);
xyz = [fabric(:,1)-min(fabric(:,1)) fabric(:,2)-min(fabric(:,2)) fabric(:,3)-min(fabric(:,3))];
xyzIndex = int16(xyz/dr + 1);

if time == 1
    xn = max(xyzIndex(:,1));    yn = max(xyzIndex(:,2));    zn = max(xyzIndex(:,3));
end

S11 = zeros(xn, yn, zn);    S12 = zeros(xn, yn, zn);    S13 = zeros(xn, yn, zn);
S22 = zeros(xn, yn, zn);    S23 = zeros(xn, yn, zn);    S33 = zeros(xn, yn, zn);

if time == 1
    S11Ave = zeros(xn, yn, zn);     S12Ave = zeros(xn, yn, zn);     S13Ave = zeros(xn, yn, zn);
    S22Ave = zeros(xn, yn, zn);     S23Ave = zeros(xn, yn, zn);     S33Ave = zeros(xn, yn, zn);
end

for cnt = 1 : size(xyzIndex,1)
    if xyzIndex(cnt,1) <= xn && xyzIndex(cnt,1) > 0 && xyzIndex(cnt,2) < yn && xyzIndex(cnt,2) > 0 && xyzIndex(cnt,3) < zn && xyzIndex(cnt,3) > 0
        S11(xyzIndex(cnt,1),xyzIndex(cnt,2),xyzIndex(cnt,3)) = fabric(cnt,4)*scaling;
        S12(xyzIndex(cnt,1),xyzIndex(cnt,2),xyzIndex(cnt,3)) = fabric(cnt,5)*scaling;
        S13(xyzIndex(cnt,1),xyzIndex(cnt,2),xyzIndex(cnt,3)) = fabric(cnt,6)*scaling;
        S22(xyzIndex(cnt,1),xyzIndex(cnt,2),xyzIndex(cnt,3)) = fabric(cnt,8)*scaling;
        S23(xyzIndex(cnt,1),xyzIndex(cnt,2),xyzIndex(cnt,3)) = fabric(cnt,9)*scaling;
        S33(xyzIndex(cnt,1),xyzIndex(cnt,2),xyzIndex(cnt,3)) = fabric(cnt,12)*scaling;
    end
end

S11Ave = S11Ave + S11;   S12Ave = S12Ave + S12;   S13Ave = S13Ave + S13;
S22Ave = S22Ave + S22;   S23Ave = S23Ave + S23;   S33Ave = S33Ave + S33;
end

S11Ave = S11Ave/tfinal;
S12Ave = S12Ave/tfinal;
S13Ave = S13Ave/tfinal;
S22Ave = S22Ave/tfinal;
S23Ave = S23Ave/tfinal;
S33Ave = S33Ave/tfinal;

%%%%%%%%%%%%%%% time average finished %%%%%%%%%%%%%%%%%%%%%%%%%%%%
disp(['start gaussian blur process!']);
[kx, ky, kz] = build_freq3d(S11Ave);
kernel = exp(-(kx.^2+ky.^2+kz.^2)*(sigma^2)/2);
%kernel = permute(kernel,[1 2 3]);
blurS11 = real(ifftn(kernel.*fftn(S11Ave)));
blurS11Out = [dirPath 'smoothS11.mat'];
save(blurS11Out, 'blurS11', '-v7.3');
disp('S11 done!');
clear blurS11;

blurS12 = real(ifftn(kernel.*fftn(S12Ave)));
blurS12Out = [dirPath 'smoothS12.mat'];
save(blurS12Out, 'blurS12', '-v7.3');
disp('S12 done!');
clear blurS12;

blurS13 = real(ifftn(kernel.*fftn(S13Ave)));
blurS13Out = [dirPath 'smoothS13.mat'];
save(blurS13Out, 'blurS13', '-v7.3');
disp('S13 done!');
clear blurS13;

blurS22 = real(ifftn(kernel.*fftn(S22Ave)));
blurS22Out = [dirPath 'smoothS22.mat'];
save(blurS22Out, 'blurS22', '-v7.3');
disp('S22 done!');
clear blurS22;

blurS23 = real(ifftn(kernel.*fftn(S23Ave)));
blurS23Out = [dirPath 'smoothS23.mat'];
save(blurS23Out, 'blurS23', '-v7.3');
disp('S23 done!');
clear blurS23;

blurS33 = real(ifftn(kernel.*fftn(S33Ave)))*2.45;
blurS33Out = [dirPath 'smoothS33.mat'];
save(blurS33Out, 'blurS33', '-v7.3');
disp('S33 done!');
clear blurS33;


end