function fabric2stress2D(dirPath, dr, pDia, cutoff, filterSize)

kbT = 300*1.38*10^-23;          % Thermal energy
a = pDia/2;                     % Particle radius
delta = (cutoff-pDia);          % Shell thickness
%dr = 0.12;                      % Grid resolution
vBox = (dr*10^-6)^2;            % Local area for calculating pointwise stress
%vBox = pi*(dr/2*10^-6)^2;            % Local area for calculating pointwise stress
scaling = kbT*(a/delta)/vBox;   % Prefactor in fron of fabric
sigma = filterSize;             % Smoothing filter size
Files = dir([dirPath '/*.csv']);
tfinal = length(Files);
fprintf(['We have ' num2str(tfinal) ' frames\n']);

for time = 1:tfinal
fileInPath = [dirPath Files(time).name];
fabric = csvread(fileInPath);
fprintf([fileInPath '\n']);
xyz = [fabric(:,1)-min(fabric(:,1)) fabric(:,2)-min(fabric(:,2))];
xyzIndex = int16(xyz/dr + 1);

if time == 1
    xn = max(xyzIndex(:,1));    yn = max(xyzIndex(:,2));
end

S11 = zeros(xn, yn);    S12 = zeros(xn, yn);    S22 = zeros(xn, yn);

if time == 1
    S11Ave = zeros(xn, yn); S12Ave = zeros(xn, yn); S22Ave = zeros(xn, yn);
end

for cnt = 1 : size(xyzIndex,1)
    if xyzIndex(cnt,1) <= xn && xyzIndex(cnt,1) > 0 && xyzIndex(cnt,2) < yn && xyzIndex(cnt,2) > 0
        S11(xyzIndex(cnt,1),xyzIndex(cnt,2)) = fabric(cnt,4)*scaling;
        S12(xyzIndex(cnt,1),xyzIndex(cnt,2)) = fabric(cnt,5)*scaling;
        S22(xyzIndex(cnt,1),xyzIndex(cnt,2)) = fabric(cnt,8)*scaling;
    end
end

S11Ave = S11Ave + S11;  S12Ave = S12Ave + S12;  S22Ave = S22Ave + S22;
end

S11Ave = S11Ave/tfinal;
S12Ave = S12Ave/tfinal;
S22Ave = S22Ave/tfinal;

%%%%%%%%%%%%%%% time average finished %%%%%%%%%%%%%%%%%%%%%%%%%%%%
disp(['start gaussian blur process!']);
[kx, ky] = build_freq2d(S11Ave);
kernel = exp(-(kx.^2+ky.^2)*(sigma^2)/2)';
blurS11 = real(ifftn(kernel.*fftn(S11Ave)));
blurS11Out = [dirPath 'smoothS11.mat'];
save(blurS11Out, 'blurS11', '-v7.3');
disp('S11 done!');
clear blurS11;

blurS12 = real(ifftn(kernel.*fftn(S12Ave)));
blurS12Out = [dirPath 'smoothS12.mat'];
save(blurS12Out, 'blurS12', '-v7.3');
disp('S12 done!');
clear blurS12;

blurS22 = real(ifftn(kernel.*fftn(S22Ave)));
blurS22Out = [dirPath 'smoothS22.mat'];
save(blurS22Out, 'blurS22', '-v7.3');
disp('S22 done!');
clear blurS22;


end