%%%%%%%%%%%%%%%%%%%%
% OVERALL FLOW
% This code calculates the fabric tensor at the particle-level given all
% particle positions. This code calculates the fabric tensor in THREE steps:
% Step 1: Find each particle's colliding neighbors
% Step 2: Calculate all the relative vectors
% Step 3: Use the unit relative vectors to calculate the fabric tensor
%%%%%%%%%%%%%%%%%%%%

%%%%%%%%%%%%%%%%%%%%
% Inputs:
% fileIn: String, Position file path (un-scaled, in pixel)
% fileOut: String, Output file path (csvfile)
% cutoff: Scaler, Outer shell radius (in micron)
% xyzScaling: 1X3 vector, scaling for x, y, and z pixels
%%%%%%%%%%%%%%%%%%%%


%%%%%%%%%%%%%%%%%%%%
% File format:
%In put file format: typical Crocker-Grier routine output file is fine
% Columns 1, 2, 3 correspond to position x, y, z, respectively.
% The output file contain the x, y, z positions (columns 1, 2, 3), and the
% fabric tensor components (columns: 4-12: xx, xy, xz, yx, yy, yz, zx, zy,
% zz). The final column (column 13) denotes the number of colliding
% neighbors.
%%%%%%%%%%%%%%%%%%%%%

function fabric_delta(fileIn, fileOut, cutoff, xyzScaling)

filein  = fileIn;
fileout = fileOut;
fprintf([filein '\n']);
data = csvread(filein);

%%%%% Scale the xyz %%%%%%
data(:,1)=data(:,1)*xyzScaling(1);
data(:,2)=data(:,2)*xyzScaling(2);
data(:,3)=data(:,3)*xyzScaling(3);
%%%%%%%%%%%%%%%%%%%%%%%%%%

fabric = zeros(size(data,1),10);

for partcnt = 1:size(data,1)
    RevVector = data(:,1:3) - repmat( data(partcnt,1:3), size(data,1),1 );
    temp=RevVector( sum(RevVector(:,1:3).^2,2) < cutoff^2 ...
        & sum(RevVector(:,1:3).^2,2) > 0, 1:3);
    if size(temp,1) >= 1
        for i =1:size(temp,1)
            VectorLength = norm(temp(i,1:3));
            temp(i,1:3) = [temp(i,1)/(VectorLength) ...
                temp(i,2)/(VectorLength) ...
                temp(i,3)/(VectorLength) ];
        end
        fabric(partcnt, :) = [sum( temp(:,1).*temp(:,1) ,1)  sum( temp(:,1).*temp(:,2) ,1) sum( temp(:,1).*temp(:,3) ,1)...
            sum( temp(:,2).*temp(:,1) ,1) sum( temp(:,2).*temp(:,2) ,1) sum( temp(:,2).*temp(:,3) ,1)...
            sum( temp(:,3).*temp(:,1) ,1)  sum( temp(:,3).*temp(:,2) ,1)  sum( temp(:,3).*temp(:,3) ,1) size(temp,1) ];
    end
end
fabricOut = [data(:,1:3) fabric];
csvwrite(fileout, fabricOut);
end
